Struct phm::Machine

source · []
pub struct Machine { /* private fields */ }
The Pretty HAL Machine

This wraps a serial port connection to an embedded machine, and implements various embedded-hal traits.

Implementations

Set the timeout for a full command to complete.

This is not a single message timeout, but rather the timeout for a whole command (e.g. an I2C write) to execute. This is currently only checked/set host side, so endless loops on the embedded side are still possible.